"use strict";
function __export(m) {
    for (var p in m) if (!exports.hasOwnProperty(p)) exports[p] = m[p];
}
Object.defineProperty(exports, "__esModule", { value: true });
var color_1 = require("tns-core-modules/color");
var frame_1 = require("tns-core-modules/ui/frame");
var snackbar_common_1 = require("./snackbar.common");
__export(require("./snackbar.common"));
var SnackBar = (function () {
    function SnackBar() {
    }
    SnackBar.prototype.simple = function (snackText, textColor, backgroundColor, maxLines, isRTL, view) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                if (!snackText) {
                    reject('Snack text is required.');
                    return;
                }
                var attachToView = (view && view.android) || frame_1.topmost().currentPage.android;
                _this._snackbar = android.support.design.widget.Snackbar.make(attachToView, snackText, 3000);
                _this._snackbar.setText(snackText);
                if (textColor && color_1.Color.isValid(textColor)) {
                    _this._setTextColor(textColor);
                }
                if (backgroundColor && color_1.Color.isValid(backgroundColor)) {
                    _this._setBackgroundColor(backgroundColor);
                }
                var cb = new TNS_BaseCallback(new WeakRef(_this));
                cb.resolve = resolve;
                _this._snackbar.addCallback(cb);
                if (maxLines) {
                    var sbView = _this._snackbar.getView();
                    var tv = sbView.findViewById(SnackBar.SNACKBAR_TEXT_ID);
                    tv.setMaxLines(maxLines);
                }
                if (isRTL === true) {
                    var sbView = _this._snackbar.getView();
                    var tv = sbView.findViewById(SnackBar.SNACKBAR_TEXT_ID);
                    tv.setLayoutDirection(android.view.View.LAYOUT_DIRECTION_RTL);
                }
                _this._snackbar.show();
            }
            catch (ex) {
                reject(ex);
            }
        });
    };
    SnackBar.prototype.action = function (options) {
        var _this = this;
        return new Promise(function (resolve, reject) {
            try {
                options.actionText = options.actionText ? options.actionText : 'Close';
                options.hideDelay = options.hideDelay ? options.hideDelay : 3000;
                var attachToView = (options.view && options.view.android) ||
                    frame_1.topmost().currentPage.android;
                _this._snackbar = android.support.design.widget.Snackbar.make(attachToView, options.snackText, options.hideDelay);
                _this._snackbar.setText(options.snackText);
                _this._snackbar.setDuration(options.hideDelay);
                var listener = new android.view.View.OnClickListener({
                    onClick: function (args) {
                        resolve({
                            command: 'Action',
                            reason: _this._getReason(1),
                            event: args
                        });
                    }
                });
                _this._snackbar.setAction(options.actionText, listener);
                if (options.textColor && color_1.Color.isValid(options.textColor)) {
                    _this._setTextColor(options.textColor);
                }
                if (options.actionTextColor && color_1.Color.isValid(options.actionTextColor)) {
                    _this._snackbar.setActionTextColor(new color_1.Color(options.actionTextColor).android);
                }
                if (options.backgroundColor && color_1.Color.isValid(options.backgroundColor)) {
                    _this._setBackgroundColor(options.backgroundColor);
                }
                if (options.maxLines) {
                    var sbView = _this._snackbar.getView();
                    var tv = sbView.findViewById(SnackBar.SNACKBAR_TEXT_ID);
                    tv.setMaxLines(options.maxLines);
                }
                if (options.isRTL === true) {
                    var sbView = _this._snackbar.getView();
                    var tv = sbView.findViewById(SnackBar.SNACKBAR_TEXT_ID);
                    tv.setLayoutDirection(android.view.View.LAYOUT_DIRECTION_RTL);
                }
                var cb = new TNS_BaseCallback(new WeakRef(_this));
                cb.resolve = resolve;
                _this._snackbar.addCallback(cb);
                _this._snackbar.show();
            }
            catch (ex) {
                reject(ex);
            }
        });
    };
    SnackBar.prototype.dismiss = function () {
        var _this = this;
        return new Promise(function (resolve, reject) {
            if (_this._snackbar) {
                try {
                    _this._snackbar.dismiss();
                    setTimeout(function () {
                        resolve({
                            action: 'Dismiss',
                            reason: _this._getReason(3)
                        });
                    }, 200);
                }
                catch (ex) {
                    reject(ex);
                }
            }
            else {
                resolve({
                    action: 'None',
                    message: 'No actionbar to dismiss'
                });
            }
        });
    };
    SnackBar.prototype._getReason = function (value) {
        switch (value) {
            case android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_SWIPE:
                return snackbar_common_1.DismissReasons.SWIPE;
            case android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_ACTION:
                return snackbar_common_1.DismissReasons.ACTION;
            case android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_TIMEOUT:
                return snackbar_common_1.DismissReasons.TIMEOUT;
            case android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_MANUAL:
                return snackbar_common_1.DismissReasons.MANUAL;
            case android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_CONSECUTIVE:
                return snackbar_common_1.DismissReasons.CONSECUTIVE;
            default:
                return snackbar_common_1.DismissReasons.UNKNOWN;
        }
    };
    SnackBar.prototype._setBackgroundColor = function (color) {
        if (color) {
            var sbView = this._snackbar.getView();
            sbView.setBackgroundColor(new color_1.Color(color).android);
        }
    };
    SnackBar.prototype._setTextColor = function (color) {
        if (color) {
            var mainTextView = this._snackbar
                .getView()
                .findViewById(SnackBar.SNACKBAR_TEXT_ID);
            mainTextView.setTextColor(new color_1.Color(color).android);
        }
    };
    SnackBar.SNACKBAR_TEXT_ID = android.support.design.R.id
        .snackbar_text;
    return SnackBar;
}());
exports.SnackBar = SnackBar;
var TNS_BaseCallback = (function (_super) {
    __extends(TNS_BaseCallback, _super);
    function TNS_BaseCallback(owner) {
        var _this = _super.call(this) || this;
        _this.resolve = null;
        _this._owner = owner;
        return global.__native(_this);
    }
    TNS_BaseCallback.prototype.onDismissed = function (snackbar, event) {
        if (event !==
            android.support.design.widget.BaseTransientBottomBar.BaseCallback
                .DISMISS_EVENT_ACTION) {
            this.resolve({
                command: 'Dismiss',
                reason: this._owner.get()._getReason(event),
                event: event
            });
        }
    };
    TNS_BaseCallback.prototype.onShown = function (snackbar) {
    };
    return TNS_BaseCallback;
}(android.support.design.widget
    .BaseTransientBottomBar.BaseCallback));
exports.TNS_BaseCallback = TNS_BaseCallback;
//# sourceMappingURL=snackbar.android.js.map